| Title: | Real-Time PCR Data Sets by Batsch et al. (2008) |
|---|---|
| Description: | Real-time quantitative polymerase chain reaction (qPCR) data sets by Batsch et al. (2008) <doi:10.1186/1471-2105-9-95>. This package provides five data sets, one for each PCR target: (i) rat SLC6A14, (ii) human SLC22A13, (iii) pig EMT, (iv) chicken ETT, and (v) human GAPDH. Each data set comprises a five-point, four-fold dilution series. For each concentration there are three replicates. Each amplification curve is 45 cycles long. Original raw data file: <https://static-content.springer.com/esm/art%3A10.1186%2F1471-2105-9-95/MediaObjects/12859_2007_2080_MOESM5_ESM.xls>. |
| Authors: | Ramiro Magno [aut, cre] (ORCID: <https://orcid.org/0000-0001-5226-3441>), Pattern Institute [cph, fnd] |
| Maintainer: | Ramiro Magno <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.1.1 |
| Built: | 2026-05-13 05:52:00 UTC |
| Source: | https://github.com/ramiromagno/batsch |
Each data set comprises a five-point, four-fold dilution series. For each concentration there are three replicates. Each amplification curve is 45 cycles long.
A single reaction (total volume 10 µl) contained 1 µl master mix (LightCycler TaqMan Master; Roche 04735536001), 1 µmol/l each of forward and reverse primer, SYBR Green I at 1:30 dilution (Invitrogen S7563) or 50 nmol/l probe, and various amounts of cDNA or plasmid DNA. Contamination controls contained water instead of DNA. After enzyme activation (10 min, 95°C), thermocycling consisted of 45 cycles of 10 s at 95°C, 30 s at 55°C, and 1 s at 72°C; velocity of temperature change was 1.1°C/s. Please read the Methods section of Batsch et al. (2008) for more details.
SLC6A14r SLC22A13h EMTp ETTch GAPDHhSLC6A14r SLC22A13h EMTp ETTch GAPDHh
Each data set is provided as a tibble with 675 rows and 9 variables:
platePlate identifier. Because one plate was used per target, the
name of the plate is the same as the values in target.
wellWell identifier. Values are always NA (not available) for
these data sets. This variable is kept nevertheless to be coherent with other
data sets from other similar R data packages.
dyeEither SYBR Green I master mix (Roche) ("SYBR") or TaqMan
probe ("TaqMan").
targetTarget identifier: rat SLC6A14 ("SLC6A14r"), human SLC22A13
("SLC22A13h"), pig EMT ("EMTp"), chicken ETT ("ETTch") or human GAPDH
("GAPDHh").
sample_typeSample type (all curves are standards, i.e. "std").
replicateReplicate identifier: 1 thru 3.
dilutionDilution factor. Higher number means greater dilution.
cyclePCR cycle.
fluorRaw fluorescence values.
SLC6A14r SLC22A13h EMTp ETTch GAPDHhSLC6A14r SLC22A13h EMTp ETTch GAPDHh